pub trait Union<Rhs = Self> {
type Output;
// Required method
fn union(&self, rhs: &Rhs) -> Self::Output;
}Expand description
Defines a Set with every element of both input Sets.
S_out = { x | x in S_left or x in S_right }
pub trait Union<Rhs = Self> {
type Output;
// Required method
fn union(&self, rhs: &Rhs) -> Self::Output;
}Defines a Set with every element of both input Sets.
S_out = { x | x in S_left or x in S_right }